/*
 * spc_col.h
 * by Hirotsugu Kakugawa
 *
 *  2 June 1997  Firsyt implementation
 *
 */
/*
 * Copyright (C) 1996-2001  Hirotsugu Kakugawa. 
 * All rights reserved.
 *
 * This file is part of the DVIlib Library.  This library is free
 * software; you can redistribute it and/or modify it under the terms of
 * the GNU Library General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your
 * option) any later version.  This library is distributed in the hope
 * that it will be useful, but WITHOUT ANY WARRANTY; without even the
 * implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE.  See the GNU Library General Public License for more details.
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

Public int  dvi_special_color(DVI,DVI_DEVICE,char*,long,long);
Public int  dvi_special_bgcolor(DVI,DVI_DEVICE,char*,long,long);
Public int  dvi_special_textcolor(DVI,DVI_DEVICE,char*,long,long);
Public int  dvi_special_color_pdftex(DVI,DVI_DEVICE,char*,long,long);
Public int  dvi_special_bgcolor_pdftex(DVI,DVI_DEVICE,char*,long,long);

/* Default color: decision of acutual color is left to device drivers. */
#define COLOR_DEFAULT_RGB   "rgb -1 -1 -1"
#define COLOR_DEFAULT_CMYK  "cmyk -1 -1 -1 -1"
#define COLOR_DEFAULT_GRAY  "gray -1"

/*EOF*/
